@@ -217,6 +217,8 @@ typedef struct
 
   gboolean block_close_response;
   gboolean is_short;
+
+  GBinding *child_visible_binding;
 } AdwAlertDialogPrivate;
 
 static void adw_alert_dialog_buildable_init (GtkBuildableIface *iface);
@@ -1858,9 +1860,19 @@ adw_alert_dialog_set_extra_child (AdwAlertDialog *self,
   if (child)
     g_return_if_fail (gtk_widget_get_parent (child) == NULL);
 
+  g_clear_pointer (&priv->child_visible_binding, g_binding_unbind);
+
   priv->child = child;
   adw_bin_set_child (ADW_BIN (priv->child_bin), child);
-  gtk_widget_set_visible (priv->child_bin, child != NULL);
+
+  if (child) {
+    priv->child_visible_binding =
+      g_object_bind_property (child, "visible",
+                              priv->child_bin, "visible",
+                              G_BINDING_SYNC_CREATE);
+  } else {
+    gtk_widget_set_visible (priv->child_bin, FALSE);
+  }
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_EXTRA_CHILD]);
 }
