@@ -251,10 +251,20 @@ text_activated_cb (AdwEntryRow *self)
   if (gtk_widget_get_child_visible (priv->apply_button)) {
     apply_button_clicked_cb (self);
   } else {
+    const char *action_name;
+
     if (priv->activates_default)
       gtk_widget_activate_default (GTK_WIDGET (self));
 
     g_signal_emit (self, signals[SIGNAL_ENTRY_ACTIVATED], 0);
+
+    action_name = gtk_actionable_get_action_name (GTK_ACTIONABLE (self));
+
+    if (action_name) {
+      GVariant *target = gtk_actionable_get_action_target_value (GTK_ACTIONABLE (self));
+
+      gtk_widget_activate_action_variant (GTK_WIDGET (self), action_name, target);
+    }
   }
 }
 
@@ -382,8 +392,8 @@ allocate_editable_area (GtkWidget *widget,
     transform = gsk_transform_translate (transform, &GRAPHENE_POINT_INIT (width, 0));
   transform = gsk_transform_scale (transform, empty_scale, empty_scale);
   if (is_rtl)
-    transform = gsk_transform_translate (transform, &GRAPHENE_POINT_INIT (-width, 0));
-  gtk_widget_allocate (priv->empty_title, width, empty_height, -1, transform);
+    transform = gsk_transform_translate (transform, &GRAPHENE_POINT_INIT (icon_width - width, 0));
+  gtk_widget_allocate (priv->empty_title, width - icon_width, empty_height, -1, transform);
 
   transform = gsk_transform_translate (NULL, &GRAPHENE_POINT_INIT (0, title_offset));
   if (is_rtl)
