@@ -32,4 +32,15 @@ gboolean adw_floating_sheet_get_open (AdwFloatingSheet *self);
 void     adw_floating_sheet_set_open (AdwFloatingSheet *self,
                                       gboolean          open);
 
+gboolean adw_floating_sheet_get_can_close (AdwFloatingSheet *self);
+void     adw_floating_sheet_set_can_close (AdwFloatingSheet *self,
+                                           gboolean          can_close);
+
+GtkWidget *adw_floating_sheet_get_sheet_bin (AdwFloatingSheet *self);
+
+void adw_floating_sheet_set_callbacks (AdwFloatingSheet *self,
+                                       GFunc             closing_callback,
+                                       GFunc             closed_callback,
+                                       gpointer          user_data);
+
 G_END_DECLS
